@@ -1,5 +1,4 @@
-#ifndef __GV_DUMMY_H__
-#define __GV_DUMMY_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -10,5 +9,3 @@
 #define GV_TYPE_DUMMY gv_dummy_get_type()
 
 G_DECLARE_FINAL_TYPE(GvDummy, gv_dummy, GV, DUMMY, GvFeature)
-
-#endif /* __GV_DUMMY_H__ */
