@@ -534,9 +534,6 @@ gv_engine_play(GvEngine *self, GvStation *station)
 	/* Set station */
 	gv_engine_set_station(self, station);
 
-	/* Clear metadata */
-	gv_engine_set_metadata(self, NULL);
-
 	/* According to the doc:
 	 *
 	 * > State changes to GST_STATE_READY or GST_STATE_NULL never return
@@ -577,6 +574,8 @@ gv_engine_stop(GvEngine *self)
 	/* Radical way to stop: set state to NULL */
 	set_gst_state(priv->playbin, GST_STATE_NULL);
 	gv_engine_set_state(self, GV_ENGINE_STATE_STOPPED);
+	gv_engine_set_bitrate(self, 0);
+	gv_engine_set_metadata(self, NULL);
 }
 
 GvEngine *
@@ -893,9 +892,9 @@ on_bus_message_tag(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 
 		gst_tag_list_peek_string_index(taglist, GST_TAG_AUDIO_CODEC, 0, &audio_codec);
 		gst_tag_list_get_uint_index(taglist, GST_TAG_BITRATE, 0, &bitrate);
-		bitrate /= 1000;    // or 1024?
+		bitrate /= 1000;    // kilobits per second
 		gst_tag_list_get_uint_index(taglist, GST_TAG_NOMINAL_BITRATE, 0, &nominal_bitrate);
-		nominal_bitrate /= 1000;    // or 1024?
+		nominal_bitrate /= 1000;    // kilobits per second
 
 		gv_engine_set_bitrate(self, bitrate);
 
