@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,8 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_CORE_GV_PLAYER_H__
-#define __GOODVIBES_CORE_GV_PLAYER_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -65,7 +64,6 @@ GvMetadata    *gv_player_get_metadata    (GvPlayer *self);
 GvStation   *gv_player_get_station            (GvPlayer *self);
 GvStation   *gv_player_get_prev_station       (GvPlayer *self);
 GvStation   *gv_player_get_next_station       (GvPlayer *self);
-const gchar *gv_player_get_stream_uri         (GvPlayer *self);
 void         gv_player_set_station            (GvPlayer *self, GvStation *station);
 gboolean     gv_player_set_station_by_name    (GvPlayer *self, const gchar *name);
 gboolean     gv_player_set_station_by_uri     (GvPlayer *self, const gchar *uri);
@@ -88,5 +86,3 @@ gboolean     gv_player_get_pipeline_enabled(GvPlayer *self);
 void         gv_player_set_pipeline_enabled(GvPlayer *self, gboolean enabled);
 const gchar *gv_player_get_pipeline_string (GvPlayer *self);
 void         gv_player_set_pipeline_string (GvPlayer *self, const gchar *pipeline);
-
-#endif /* __GOODVIBES_CORE_GV_PLAYER_H__ */
