@@ -94,13 +94,18 @@
 /*
  * More of my favorite french radios.
  * - Grenouille <http://www.radiogrenouille.com/>
+ * - PBB <http://www2.laurentgarnier.com/PBB.html>
  */
 
 #define FRENCH_STATIONS   \
         "<Station>" \
         "  <name>Radio Grenouille</name>" \
         "  <uri>http://live.radiogrenouille.com/live</uri>" \
-        "</Station>"
+        "</Station>" \
+	"<Station>" \
+	"  <name>Pedro Basement Broadcast</name>" \
+	"  <uri>http://pbb.laurentgarnier.com:8000/pbb128</uri> " \
+	"</Station>"
 
 /*
  * Broken stations.
@@ -1568,14 +1573,6 @@ gv_station_list_constructed(GObject *object)
 	GvStationList *self = GV_STATION_LIST(object);
 	GvStationListPrivate *priv = self->priv;
 
-	/* The test suite should always set custom load/save paths */
-	if (gv_in_test_suite()) {
-		if (priv->save_path == NULL || priv->load_path == NULL) {
-			ERROR("Test suite should always set station list paths");
-			/* Program execution stops here */
-		}
-	}
-
 	/* Initialize default paths */
 	priv->default_load_paths = make_station_list_load_paths();
 	priv->default_save_path = make_station_list_save_path();
