@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,8 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_CORE_GV_STATION_LIST_H__
-#define __GOODVIBES_CORE_GV_STATION_LIST_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -39,6 +38,7 @@ typedef struct _GvStationListIter GvStationListIter;
 /* Methods */
 
 GvStationList *gv_station_list_new (void);
+GvStationList *gv_station_list_new_with_paths(const gchar *load_path, const gchar *save_path);
 
 void  gv_station_list_load  (GvStationList *self);
 void  gv_station_list_save  (GvStationList *self);
@@ -59,6 +59,7 @@ void gv_station_list_move_last  (GvStationList *self, GvStation *station);
 
 GvStation *gv_station_list_first(GvStationList *self);
 GvStation *gv_station_list_last (GvStationList *self);
+GvStation *gv_station_list_at   (GvStationList *self, guint n);
 GvStation *gv_station_list_prev (GvStationList *self, GvStation *station, gboolean repeat,
                                  gboolean shuffle);
 GvStation *gv_station_list_next (GvStationList *self, GvStation *station, gboolean repeat,
@@ -76,4 +77,7 @@ GvStationListIter *gv_station_list_iter_new (GvStationList *self);
 void               gv_station_list_iter_free(GvStationListIter *iter);
 gboolean           gv_station_list_iter_loop(GvStationListIter *iter, GvStation **station);
 
-#endif /* __GOODVIBES_CORE_GV_STATION_LIST_H__ */
+/* Property accessors */
+
+const gchar *gv_station_list_get_load_path(GvStationList *self);
+const gchar *gv_station_list_get_save_path(GvStationList *self);
