@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,8 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_CORE_GV_STATION_H__
-#define __GOODVIBES_CORE_GV_STATION_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -48,7 +47,7 @@ GSList      *gv_station_get_stream_uris     (GvStation *self);
 const gchar *gv_station_get_first_stream_uri(GvStation *self);
 const gchar *gv_station_get_user_agent      (GvStation *self);
 void         gv_station_set_user_agent      (GvStation *self, const gchar *user_agent);
+const gchar *gv_station_get_codec           (GvStation *self);
+void         gv_station_set_codec           (GvStation *self, const gchar *codec);
 guint        gv_station_get_nominal_bitrate (GvStation *self);
 void         gv_station_set_nominal_bitrate (GvStation *self, guint bitrate);
-
-#endif /* __GOODVIBES_CORE_GV_STATION_H__ */
