@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,8 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_FEAT_GV_DBUS_SERVER_NATIVE_H__
-#define __GOODVIBES_FEAT_GV_DBUS_SERVER_NATIVE_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -38,5 +37,3 @@ G_DECLARE_FINAL_TYPE(GvDbusServerNative, gv_dbus_server_native, \
 /* Public methods */
 
 GvFeature *gv_dbus_server_native_new(void);
-
-#endif /* __GOODVIBES_FEAT_GV_DBUS_SERVER_NATIVE_H__ */
