@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,8 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_FEAT_GV_DBUS_SERVER_H__
-#define __GOODVIBES_FEAT_GV_DBUS_SERVER_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -87,5 +86,3 @@ void gv_dbus_server_set_dbus_path           (GvDbusServer *self, const gchar *pa
 void gv_dbus_server_set_dbus_introspection  (GvDbusServer *self, const gchar *introspection);
 void gv_dbus_server_set_dbus_interface_table(GvDbusServer *self,
                                              GvDbusInterface *interface_table);
-
-#endif /* __GOODVIBES_FEAT_GV_DBUS_SERVER_H__ */
