@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -91,8 +91,12 @@ on_menu_item_activate(GtkMenuItem *item, GvStationContextMenu *self)
 		GvStation *station;
 
 		station = gv_show_add_station_dialog(GTK_WINDOW(gv_ui_main_window));
-		if (station)
-			gv_station_list_insert_after(station_list, station, selected_station);
+		if (station) {
+			if (selected_station)
+				gv_station_list_insert_after(station_list, station, selected_station);
+			else
+				gv_station_list_append(station_list, station);
+		}
 
 	} else if (widget == priv->edit_station_menu_item && selected_station) {
 		gv_show_edit_station_dialog(GTK_WINDOW(gv_ui_main_window), selected_station);
