@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -84,7 +84,7 @@ enum {
 
 static void
 on_player_notify_station(GvPlayer           *player,
-                         GParamSpec          *pspec G_GNUC_UNUSED,
+                         GParamSpec         *pspec G_GNUC_UNUSED,
                          GvStationsTreeView *self)
 {
 	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
@@ -93,8 +93,6 @@ on_player_notify_station(GvPlayer           *player,
 	GtkTreeIter iter;
 	gboolean can_iter;
 
-	DEBUG("Notify from player");
-
 	can_iter = gtk_tree_model_get_iter_first(tree_model, &iter);
 
 	while (can_iter) {
@@ -131,17 +129,21 @@ on_player_notify_station(GvPlayer           *player,
  */
 
 static void
-on_station_list_loaded(GvStationList *station_list G_GNUC_UNUSED,
+on_station_list_loaded(GvStationList *station_list,
                        GvStationsTreeView  *self)
 {
+	TRACE("%p, %p", station_list, self);
+
 	gv_stations_tree_view_populate(self);
 }
 
 static void
-on_station_list_station_event(GvStationList *station_list G_GNUC_UNUSED,
-                              GvStation     *station G_GNUC_UNUSED,
+on_station_list_station_event(GvStationList *station_list,
+                              GvStation     *station,
                               GvStationsTreeView *self)
 {
+	TRACE("%p, %p, %p", station_list, station, self);
+
 	gv_stations_tree_view_populate(self);
 }
 
@@ -284,7 +286,6 @@ on_tree_view_button_press_event(GvStationsTreeView *self,
 	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
 	GtkTreeModel *tree_model = gtk_tree_view_get_model(tree_view);
 	GtkTreePath *path;
-	GtkTreeIter iter;
 	GvStation *station;
 	GtkWidget *context_menu;
 
@@ -306,7 +307,7 @@ on_tree_view_button_press_event(GvStationsTreeView *self,
 
 	/* Do nothing if there's already a context menu (this case shouldn't happen) */
 	if (priv->context_menu) {
-		WARNING("Context menu already exists !");
+		WARNING("Context menu already exists!");
 		return GDK_EVENT_PROPAGATE;
 	}
 
@@ -315,14 +316,15 @@ on_tree_view_button_press_event(GvStationsTreeView *self,
 	gtk_tree_view_get_path_at_pos(tree_view, event->x, event->y,
 	                              &path, NULL, NULL, NULL);
 
-	if (path == NULL)
-		return GDK_EVENT_PROPAGATE;
-
 	/* Get corresponding station */
-	gtk_tree_model_get_iter(tree_model, &iter, path);
-	gtk_tree_model_get(tree_model, &iter,
-	                   STATION_COLUMN, &station,
-	                   -1);
+	station = NULL;
+	if (path != NULL) {
+		GtkTreeIter iter;
+		gtk_tree_model_get_iter(tree_model, &iter, path);
+		gtk_tree_model_get(tree_model, &iter,
+		                   STATION_COLUMN, &station,
+		                   -1);
+	}
 
 	/* Create the context menu */
 	if (station) {
@@ -453,6 +455,7 @@ on_list_store_row_changed(GtkTreeModel        *tree_model,
                           GvStationsTreeView *self)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
+	GvStation *station;
 	gint *indices;
 	gint position;
 
@@ -472,7 +475,6 @@ on_list_store_row_changed(GtkTreeModel        *tree_model,
 	}
 
 	/* Get station */
-	GvStation *station;
 	gtk_tree_model_get(tree_model, iter,
 	                   STATION_COLUMN, &station,
 	                   -1);
@@ -488,39 +490,40 @@ on_list_store_row_changed(GtkTreeModel        *tree_model,
 
 static void
 on_list_store_row_deleted(GtkTreeModel        *tree_model G_GNUC_UNUSED,
-                          GtkTreePath         *path,
+                          GtkTreePath         *path G_GNUC_UNUSED,
                           GvStationsTreeView *self)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
-	gint *indices;
-	guint indice_deleted, indice_inserted;
+	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
+	GvStationList *station_list = gv_core_station_list;
+	GtkTreeSelection *select;
+	GvStation *station;
+	guint indice_inserted;
 
 	/* End of drag operation, let's commit that to station list */
-	GvStation *station = priv->station_dragged;
+	station = priv->station_dragged;
 	if (station == NULL) {
-		WARNING("Station dragged is null, wtf ?");
+		WARNING("Station dragged is null, wtf?");
 		return;
 	}
 
-	/* Compute indice */
-	indices = gtk_tree_path_get_indices(path);
-	indice_deleted = indices[0];
-	indice_inserted = priv->station_new_pos;
-	if (indice_deleted < indice_inserted)
-		indice_inserted -= 1;
-
 	/* Move station in the station list */
-	GvStationList *station_list = gv_core_station_list;
-
+	indice_inserted = priv->station_new_pos;
 	g_signal_handlers_block(station_list, station_list_handlers, self);
 	gv_station_list_move(station_list, station, indice_inserted);
 	g_signal_handlers_unblock(station_list, station_list_handlers, self);
-
-	DEBUG("Row deleted, moving sta at %d", indice_inserted);
+	DEBUG("Row deleted, station moved at %d", indice_inserted);
 
 	/* Clean status */
 	priv->station_dragged = NULL;
 	priv->station_new_pos = -1;
+
+	/* Reset selection, as GTK doesn't do it itself, hence the column that
+	 * was selected (ie. highlighted as we're in hover selection mode)
+	 * before the drag'n'drop is highligted again after the drag'n'drop.
+	 */
+	select = gtk_tree_view_get_selection(tree_view);
+	gtk_tree_selection_unselect_all(select);
 }
 
 static GSignalHandler list_store_handlers[] = {
