@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -36,15 +36,20 @@
 
 #include "ui/gv-status-icon.h"
 
-#define UI_RESOURCE_PATH GV_APPLICATION_PATH "/Ui/status-icon-menu.glade"
+/* This file uses the GtkStatusIcon object, which is deprecated in GTK 3.x.
+ * Let's silence the warning to keep the compiler output readable.
+ */
+
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+
 #define ICON_MIN_SIZE 16
 
 /*
  * Properties
  */
 
-#define DEFAULT_MIDDLE_CLICK_ACTION "toggle"
-#define DEFAULT_SCROLL_ACTION       "station"
+#define DEFAULT_MIDDLE_CLICK_ACTION GV_STATUS_ICON_MIDDLE_CLICK_TOGGLE
+#define DEFAULT_SCROLL_ACTION       GV_STATUS_ICON_SCROLL_STATION
 
 enum {
 	/* Reserved */
@@ -101,7 +106,7 @@ gv_status_icon_update_icon_pixbuf(GvStatusIcon *self)
 	GvStatusIconPrivate *priv = self->priv;
 	GtkStatusIcon *status_icon = priv->status_icon;
 
-	gtk_status_icon_set_from_icon_name(status_icon, PACKAGE_NAME);
+	gtk_status_icon_set_from_icon_name(status_icon, GV_ICON_NAME);
 }
 
 static void
@@ -505,25 +510,19 @@ static void
 gv_status_icon_setup_menu(GvStatusIcon *self)
 {
 	GvStatusIconPrivate *priv = self->priv;
-	GtkBuilder *builder;
-	GMenuModel *model;
+	GtkWindow *main_window = priv->main_window;
+	GMenuModel *menu_model;
 	GtkWidget *menu;
 
-	/* Load the menu model */
-	builder = gtk_builder_new_from_resource(UI_RESOURCE_PATH);
-
 	/* Build the menu */
-	model = G_MENU_MODEL(gtk_builder_get_object(builder, "status-icon-menu"));
-	menu = gtk_menu_new_from_model(model);
+	menu_model = gv_main_window_get_primary_menu(GV_MAIN_WINDOW(main_window));
+	menu = gtk_menu_new_from_model(menu_model);
 
 	/* Attach to main window */
 	gtk_menu_attach_to_widget(GTK_MENU(menu), GTK_WIDGET(priv->main_window), NULL);
 
 	/* Save a pointer */
 	priv->popup_menu = g_object_ref_sink(menu);
-
-	/* Cleanup */
-	g_object_unref(builder);
 }
 
 static void
@@ -599,13 +598,13 @@ gv_status_icon_class_init(GvStatusIconClass *class)
 	properties[PROP_MIDDLE_CLICK_ACTION] =
 	        g_param_spec_enum("middle-click-action", "Middle click action", NULL,
 	                          GV_TYPE_STATUS_ICON_MIDDLE_CLICK,
-	                          GV_STATUS_ICON_MIDDLE_CLICK_TOGGLE,
+	                          DEFAULT_MIDDLE_CLICK_ACTION,
 	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
 
 	properties[PROP_SCROLL_ACTION] =
 	        g_param_spec_enum("scroll-action", "Scroll action", NULL,
 	                          GV_TYPE_STATUS_ICON_SCROLL,
-	                          GV_STATUS_ICON_SCROLL_STATION,
+	                          DEFAULT_SCROLL_ACTION,
 	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
